@@ -47,18 +47,40 @@ setValidity("PictureClipPath",
                 all(sapply(object@content, is, "PictureContent"))
             })
 
+setClass("PictureFeImage",
+         representation("PictureContent",
+                        href = "character",
+                        result = "character",
+                        x = "numeric",
+                        y = "numeric",
+                        width = "numeric",
+                        height = "numeric"))
+
+setClass("PictureFeComposite",
+         representation("PictureContent",
+                        input1 = "character",
+                        input2 = "character",
+                        operator = "character",
+                        k1 = "numeric",
+                        k2 = "numeric",
+                        k3 = "numeric",
+                        k4 = "numeric",
+                        colorspace = "character"))
+         
 setClass("PictureFeColorMatrix",
          representation("PictureContent",
                         type = "character",
                         input = "character",
-                        values = "matrix"))
+                        values = "matrix",
+                        colorspace = "character"))
 
 setClass("PictureFilter",
          representation("PictureContent",
                         filterUnits = "character",
+                        primitiveUnits = "character",
                         x = "numeric", y = "numeric",
                         width = "numeric", height = "numeric",
-                        content = "PictureFeColorMatrix"))
+                        content = "list"))
 
 setClass("PictureGroup",
          representation("PictureContent",
@@ -545,6 +567,29 @@ setMethod("applyTransform",
               object 
           })
 
+setMethod("applyTransform",
+          signature(object = "Picture",
+                    tm = "matrix"),
+          function(object, tm) {
+              content <- lapply(object@content, applyTransform, tm)
+              defs <- new("PictureDefinitions",
+                          content = lapply(object@defs@content,
+                                           applyTransform, tm))
+              allBounds <- lapply(content, getbbox)
+              xmin <- min(sapply(allBounds, function(x) x[1]))
+              xmax <- max(sapply(allBounds, function(x) x[2]))
+              ymin <- min(sapply(allBounds, function(x) x[3]))
+              ymax <- max(sapply(allBounds, function(x) x[4]))
+              bbox <- c(xmin, xmax, ymin, ymax)
+              summary <- new("PictureSummary",
+                             xscale = bbox[1:2],
+                             yscale = rev(bbox[3:4]))
+              new("Picture",
+                  content = content,
+                  defs = defs,
+                  summary = summary)
+          })
+
 getbboxFromList <- function(x) {
     allBounds <- lapply(x, getbbox)
     xmin <- min(sapply(allBounds, function(x) x[1]))
